@@ -15,7 +15,7 @@ from entity_classification.svc import FormEntityInference
 
 
 class EntityOrchestrator(BaseObject):
-    """ Portendo performs Predictive Classification of deepNLU parsed ASTs 
+    """ Portendo performs Predictive Classification of deepNLU parsed ASTs
 
     This Orchestration sequence requires a list of entity names
     This is a less nuanced form of classification than the schema orchestrator
@@ -43,9 +43,9 @@ class EntityOrchestrator(BaseObject):
 
         if self.isEnabledForInfo:
             self.logger.info('\n'.join([
-                "Initialized Orchestrator",
-                f"\tTotal Entity Names: {len(entity_names)}",
-                f"\tAnalyzed Entities: {self._d_entities}"]))
+                'Initialized Orchestrator',
+                f'\tTotal Entity Names: {len(entity_names)}',
+                f'\tAnalyzed Entities: {self._d_entities}']))
 
     # TODO: baseblock 0.1.22+
     @staticmethod
@@ -109,13 +109,13 @@ class EntityOrchestrator(BaseObject):
         if self.isEnabledForInfo:
             if svcresult:
                 self.logger.info('\n'.join([
-                    "Portendo Entity Orchestrator Completed",
-                    f"\tTotal Time: {str(sw)}",
-                    f"\tResult:\n{pformat(svcresult)}"]))
+                    'Portendo Entity Orchestrator Completed',
+                    f'\tTotal Time: {str(sw)}',
+                    f'\tResult:\n{pformat(svcresult)}']))
             else:
                 self.logger.info('\n'.join([
-                    "Portendo Entity Orchestrator Completed",
-                    f"\tTotal Time: {str(sw)}",
-                    f"\tNo Entity Inference Performed"]))
+                    'Portendo Entity Orchestrator Completed',
+                    f'\tTotal Time: {str(sw)}',
+                    f'\tNo Entity Inference Performed']))
 
         return svcresult
